import phonenumbers
import sipmediaapp
import siprule


def handler(event, context):
    print(event)
    responseData = {}
    properties = event["ResourceProperties"]["properties"]
    uid = event["ResourceProperties"]["uid"]
    if event["RequestType"] == "Create":
        if event["ResourceProperties"]["resourceType"] == "PhoneNumber":
            try:
                responseData["phoneNumber"] = phonenumbers.getPhoneNumber(uid, **properties)
                return {"PhysicalResourceId": uid, "Data": responseData}
            except Exception as e:
                error = {"error": f"Exception thrown: {e}"}
                print(error)
                raise Exception(error)
        if event["ResourceProperties"]["resourceType"] == "VoiceConnector":
            try:
                responseData = {"Message": "Create VoiceConnector not build yet."}
                return {"PhysicalResourceId": uid, "Data": responseData}
            except Exception as e:
                error = {"error": f"Exception thrown: {e}"}
                print(error)
                raise Exception(error)
        if event["ResourceProperties"]["resourceType"] == "SMA":
            try:
                responseData["sipMediaAppId"] = sipmediaapp.createSipMediaApp(uid, **properties)
                return {"PhysicalResourceId": uid, "Data": responseData}
            except Exception as e:
                error = {"error": f"Exception thrown: {e}"}
                print(error)
                raise Exception(error)
        if event["ResourceProperties"]["resourceType"] == "SMARule":
            try:
                responseData["sipRuleId"] = siprule.createSipRule(uid, **properties)
                return {"PhysicalResourceId": uid, "Data": responseData}
            except Exception as e:
                error = {"error": f"Exception thrown: {e}"}
                print(error)
                raise Exception(error)

    elif event["RequestType"] == "Delete":
        if event["ResourceProperties"]["resourceType"] == "PhoneNumber":
            try:
                responseData["phoneNumber"] = phonenumbers.deletePhoneNumber(uid)
                return {"Data": responseData}
            except Exception as e:
                error = {"error": f"Exception thrown: {e}"}
                print(error)
                raise Exception(error)
        if event["ResourceProperties"]["resourceType"] == "VoiceConnector":
            try:
                responseData = {"Message": "Delete VoiceConnector not build yet."}
                return {"Data": responseData}
            except Exception as e:
                error = {"error": f"Exception thrown: {e}"}
                print(error)
                raise Exception(error)
        if event["ResourceProperties"]["resourceType"] == "SMA":
            try:
                responseData["sipMediaAppId"] = sipmediaapp.deleteSipMediaApp(uid)
                return {"Data": responseData}
            except Exception as e:
                error = {"error": f"Exception thrown: {e}"}
                print(error)
                raise Exception(error)
        if event["ResourceProperties"]["resourceType"] == "SMARule":
            try:
                responseData["sipMediaAppId"] = siprule.deleteSipRule(uid, **properties)
                return {"Data": responseData}
            except Exception as e:
                error = {"error": f"Exception thrown: {e}"}
                print(error)
                raise Exception(error)

    else:
        responseData = {"Message": "Update is no-op. Returning success status."}
        return {"PhysicalResourceId": uid, "Data": responseData}
