import boto3
import uuid

chime = boto3.client("chime")


def createVoiceConnector(region, phoneNumber):
    print(str(uuid.uuid1()))
    print(region)
    response = chime.create_voice_connector(Name="Trunk" + str(uuid.uuid1()), AwsRegion=region, RequireEncryption=False)

    voiceConnectorId = response["VoiceConnector"]["VoiceConnectorId"]
    outboundHostName = response["VoiceConnector"]["OutboundHostName"]
    response = chime.associate_phone_numbers_with_voice_connector(
        VoiceConnectorId=voiceConnectorId,
        E164PhoneNumbers=[
            phoneNumber,
        ],
        ForceAssociate=True,
    )
    chime.put_voice_connector_streaming_configuration(
        VoiceConnectorId=voiceConnectorId,
        StreamingConfiguration={
            "DataRetentionInHours": 1,
            "Disabled": False,
            "StreamingNotificationTargets": [
                {"NotificationTarget": "EventBridge"},
            ],
        },
    )
    voiceConnector = {
        "voiceConnectorId": voiceConnectorId,
        "outboundHostName": outboundHostName,
        "phoneNumber": phoneNumber,
    }
    return voiceConnector


def authorizeEIP(voiceConnectorId, elasticIP):
    response = chime.put_voice_connector_origination(
        VoiceConnectorId=voiceConnectorId,
        Origination={
            "Routes": [
                {"Host": elasticIP, "Port": 5060, "Protocol": "UDP", "Priority": 1, "Weight": 1},
            ],
            "Disabled": False,
        },
    )
    print(response)
    response = chime.put_voice_connector_termination(
        VoiceConnectorId=voiceConnectorId,
        Termination={
            "CpsLimit": 1,
            "CallingRegions": [
                "US",
            ],
            "CidrAllowedList": [
                elasticIP + "/32",
            ],
            "Disabled": False,
        },
    )
    print(response)
